package com.github.umer0586.droidpad.uitests

import androidx.compose.ui.test.assert
import androidx.compose.ui.test.assertIsNotEnabled
import androidx.compose.ui.test.hasText
import androidx.compose.ui.test.junit4.createComposeRule
import androidx.compose.ui.test.onNodeWithTag
import androidx.compose.ui.test.performClick
import androidx.compose.ui.test.performTextReplacement
import com.github.umer0586.droidpad.data.database.entities.ControlPadItem
import com.github.umer0586.droidpad.data.database.entities.ItemType
import com.github.umer0586.droidpad.data.ButtonProperties
import com.github.umer0586.droidpad.data.LabelProperties
import com.github.umer0586.droidpad.data.SliderProperties
import com.github.umer0586.droidpad.ui.components.propertieseditor.ItemPropertiesEditorSheet
import org.junit.Assert.assertEquals
import org.junit.Assert.fail
import org.junit.Ignore
import org.junit.Rule
import org.junit.Test
import org.junit.runner.RunWith
import org.robolectric.RobolectricTestRunner

@RunWith(RobolectricTestRunner::class)
class ItemEditorTest {
    @get:Rule
    val composeTestRule = createComposeRule()

    // TODO: Check this later
    @Ignore("This test is failing but code works fine on device")
    @Test
    fun `test item identifier modification`(){
        val controlPadItem = ControlPadItem(
            id = 1,
            itemIdentifier = "slider1",
            controlPadId = 1,
            itemType = ItemType.SLIDER,
        )

        var modifiedControlPadItem : ControlPadItem? = null
        composeTestRule.setContent {
            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = { modifiedControlPadItem = it },
                itemIdentifierMaxLength = 10
            )
        }

        composeTestRule.onNodeWithTag("itemIdentifierTextField")
            .performTextReplacement("slider2")
        composeTestRule.onNodeWithTag("saveBtn").performClick()

        modifiedControlPadItem?.let { modifiedItem ->
            assertEquals("slider2", modifiedItem.itemIdentifier)
        } ?: fail("modifiedControlPadItem should not be null")

    }

    // TODO: Check this later
    @Ignore("This test is failing but code works fine on device")
    @Test
    fun `test slider properties modification`(){

        var modifiedControlPadItem : ControlPadItem? = null

        composeTestRule.setContent {
            val controlPadItem = ControlPadItem(
                id = 1,
                itemIdentifier = "slider1",
                controlPadId = 1,
                itemType = ItemType.SLIDER
            )


            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = { modifiedControlPadItem = it }
            )
        }

        composeTestRule.onNodeWithTag("sliderMinValueTextField")
            .performTextReplacement("20")


        composeTestRule.onNodeWithTag("sliderMaxValueTextField")
            .performTextReplacement("60")

        composeTestRule.onNodeWithTag("saveBtn").performClick()

        modifiedControlPadItem?.let { modifiedItem ->
            assertEquals(
                SliderProperties(minValue = 20f, maxValue = 60f),
                SliderProperties.fromJson(modifiedItem.properties)
            )
        } ?: fail("modifiedControlPadItem should not be null")

    }

    //Editor should display the properties of the item specified
    @Test
    fun `Editor interface should display slider properties of the item specified`(){

        val sliderProperties = SliderProperties(minValue = 20f, maxValue = 60f)

        composeTestRule.setContent {
            val controlPadItem = ControlPadItem(
                id = 1,
                itemIdentifier = "slider1",
                controlPadId = 1,
                itemType = ItemType.SLIDER,
                properties = sliderProperties.toJson()
                )

            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = {}
            )
        }

        composeTestRule.onNodeWithTag("sliderMinValueTextField")
            .assert(hasText(sliderProperties.minValue.toString()))

        composeTestRule.onNodeWithTag("sliderMaxValueTextField")
            .assert(hasText(sliderProperties.maxValue.toString()))


    }


    @Test
    fun `test slider min value greater than max value`(){


        composeTestRule.setContent {
            val controlPadItem = ControlPadItem(
                id = 1,
                itemIdentifier = "slider1",
                controlPadId = 1,
                itemType = ItemType.SLIDER
            )


            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = {}
            )
        }

        composeTestRule.onNodeWithTag("sliderMinValueTextField")
            .performTextReplacement("50")


        composeTestRule.onNodeWithTag("sliderMaxValueTextField")
            .performTextReplacement("10")

        composeTestRule.onNodeWithTag("saveBtn").assertIsNotEnabled()

    }

    @Test
    fun `test label modification`(){

        var modifiedControlPadItem : ControlPadItem? = null

        composeTestRule.setContent {
            val controlPadItem = ControlPadItem(
                id = 1,
                itemIdentifier = "label",
                controlPadId = 1,
                itemType = ItemType.LABEL,
                properties = "{}"
            )


            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = { modifiedControlPadItem = it }
            )
        }

        composeTestRule.onNodeWithTag("labelTextField")
            .performTextReplacement("myLabel")
        composeTestRule.onNodeWithTag("saveBtn").performClick()

        modifiedControlPadItem?.let { modifiedItem ->
            assertEquals(
                LabelProperties("myLabel"),
                LabelProperties.fromJson(modifiedItem.properties)
            )
        } ?: fail("modifiedControlPadItem should not be null")

    }

    @Test
    fun `test button text modification`() {
        var modifiedControlPadItem: ControlPadItem? = null
        composeTestRule.setContent {
            val controlPadItem = ControlPadItem(
                id = 1,
                itemIdentifier = "button",
                controlPadId = 1,
                itemType = ItemType.BUTTON
            )
            ItemPropertiesEditorSheet(
                controlPadItem = controlPadItem,
                onSaveSubmit = { modifiedControlPadItem = it }
            )
        }

        composeTestRule.onNodeWithTag("buttonTextTextField")
            .performTextReplacement("mybtn")
        composeTestRule.onNodeWithTag("saveBtn").performClick()

        modifiedControlPadItem?.let { modifiedItem ->
            assertEquals(
                ButtonProperties(text = "mybtn"),
                ButtonProperties.fromJson(modifiedItem.properties)
            )
        }

    }
}